#[non_exhaustive]pub struct AuditConfigDelta {
pub action: Action,
pub service: String,
pub exempted_member: String,
pub log_type: String,
/* private fields */
}Expand description
One delta entry for AuditConfig. Each individual change (only one exempted_member in each entry) to a AuditConfig will be a separate entry.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: ActionThe action that was performed on an audit configuration in a policy. Required
service: StringSpecifies a service that was configured for Cloud Audit Logging.
For example, storage.googleapis.com, cloudsql.googleapis.com.
allServices is a special value that covers all services.
Required
exempted_member: StringA single identity that is exempted from “data access” audit
logging for the service specified above.
Follows the same format of Binding.members.
log_type: StringSpecifies the log_type that was be enabled. ADMIN_ACTIVITY is always enabled, and cannot be configured. Required
Implementations
Sourceimpl AuditConfigDelta
impl AuditConfigDelta
pub fn new() -> Self
Sourcepub fn set_action<T: Into<Action>>(self, v: T) -> Self
pub fn set_action<T: Into<Action>>(self, v: T) -> Self
Sourcepub fn set_service<T: Into<String>>(self, v: T) -> Self
pub fn set_service<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_exempted_member<T: Into<String>>(self, v: T) -> Self
pub fn set_exempted_member<T: Into<String>>(self, v: T) -> Self
Sets the value of exempted_member.
Example
ⓘ
let x = AuditConfigDelta::new().set_exempted_member("example");Trait Implementations
Sourceimpl Clone for AuditConfigDelta
impl Clone for AuditConfigDelta
Sourcefn clone(&self) -> AuditConfigDelta
fn clone(&self) -> AuditConfigDelta
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuditConfigDelta
impl Debug for AuditConfigDelta
Sourceimpl Default for AuditConfigDelta
impl Default for AuditConfigDelta
Sourcefn default() -> AuditConfigDelta
fn default() -> AuditConfigDelta
Returns the “default value” for a type. Read more
Sourceimpl Message for AuditConfigDelta
impl Message for AuditConfigDelta
Sourceimpl PartialEq for AuditConfigDelta
impl PartialEq for AuditConfigDelta
impl StructuralPartialEq for AuditConfigDelta