GetPolicyOptions

Struct GetPolicyOptions 

#[non_exhaustive]
pub struct GetPolicyOptions { pub requested_policy_version: i32, /* private fields */ }
Encapsulates settings provided to GetIamPolicy.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
requested_policy_version: i32

Optional. The maximum policy version that will be used to format the policy.

Valid values are 0, 1, and 3. Requests specifying an invalid value will be rejected.

Requests for policies with any conditional role bindings must specify version 3. Policies with no conditional role bindings may specify any valid value or leave the field unset.

The policy in the response might use the policy version that you specified, or it might use a lower policy version. For example, if you specify version 3, but the policy has no conditional role bindings, the response uses version 1.

To learn which resources support conditions in their IAM policies, see the IAM documentation.

Implementations

Source

impl GetPolicyOptions

pub fn new() -> Self

pub fn set_requested_policy_version<T: Into<i32>>(self, v: T) -> Self

Sets the value of requested_policy_version.

Example
let x = GetPolicyOptions::new().set_requested_policy_version(42);