TestIamPermissionsRequest

Struct TestIamPermissionsRequest 

#[non_exhaustive]
pub struct TestIamPermissionsRequest { pub resource: String, pub permissions: Vec<String>, /* private fields */ }
Request message for TestIamPermissions method.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
resource: String

REQUIRED: The resource for which the policy detail is being requested. See the operation documentation for the appropriate value for this field.

permissions: Vec<String>

The set of permissions to check for the resource. Permissions with wildcards (such as ‘’ or ‘storage.’) are not allowed. For more information see IAM Overview.

Implementations

Source

impl TestIamPermissionsRequest

pub fn new() -> Self

pub fn set_resource<T: Into<String>>(self, v: T) -> Self

Sets the value of resource.

Example
let x = TestIamPermissionsRequest::new().set_resource("example");
pub fn set_permissions<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of permissions.

Example
let x = TestIamPermissionsRequest::new().set_permissions(["a", "b", "c"]);